import pytest

parametrize = pytest.mark.parametrize


class Object(object):
    def __init__(self, **attrs):
        for key, value in attrs.items():
            setattr(self, key, value)

    def __eq__(self, o: object) -> bool:
        for k, v in self.__dict__.items():
            try:
                if v != getattr(o, k):
                    return False
            except:
                return False
        return True



from typing import Dict, TypeVar, Hashable, List

V = TypeVar('V')
K = TypeVar('K', bound=Hashable)


def chunkDict(obj: Dict[K, V], size: int = 1) -> List[Dict[K, V]]:
    res = []
    if size < 1:
        raise ValueError("size must be greater 0")
    ks = list(obj)
    for i in range(len(ks)//size +(len(ks)%size != 0)):
        res.append({k: obj[k] for k in ks[i*size:(i+1)*size]})
    return res



from collections import namedtuple

import pydashlite.strings as pdl

from . import fixtures
from .fixtures import parametrize


@parametrize('case,expected', [
    ('fooBarBaz', 'fooBarBaz'),
    ('FooBarBaz', 'fooBarBaz'),
    ('FOO_BAR BAZ', 'fooBarBaz'),
    ('FOO BAR_bAz', 'fooBarBAz'),
    ('  foo  bar baz  ', 'fooBarBaz'),
    ('foo__bar_baz', 'fooBarBaz'),
    ('foo-_bar-_-baz', 'fooBarBaz'),
    (',foo!bar,baz,', 'fooBarBaz'),
    ('--foo.bar;baz', 'fooBarBaz'),
    ('', ''),
])
def test_camel_case(case, expected):
    assert pdl.camelCase(case) == expected
